@@ -36,7 +36,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 For more information, please refer to <https://unlicense.org>
 """
-from ._util import service_request, parse_id_list
+from ._util import service_request, parse_id_list, generate_error_result
 from ._service_class import ServiceClass
 
 
@@ -44,23 +44,28 @@ class Hosts(ServiceClass):
     """ The only requirement to instantiate an instance of this class
         is a valid token provided by the Falcon API SDK OAuth2 class.
     """
-    def PerformActionV2(self: object, parameters: dict, body: dict) -> dict:
+    def PerformActionV2(self: object, parameters: dict, body: dict, action_name: str) -> dict:
         """ Take various actions on the hosts in your environment.
             Contain or lift containment on a host. Delete or restore a host.
         """
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/hosts/PerformActionV2
-        FULL_URL = self.base_url+'/devices/entities/devices-actions/v2'
-        HEADERS = self.headers
-        PARAMS = parameters
-        BODY = body
-        returned = service_request(caller=self,
-                                   method="POST",
-                                   endpoint=FULL_URL,
-                                   params=PARAMS,
-                                   body=BODY,
-                                   headers=HEADERS,
-                                   verify=self.ssl_verify
-                                   )
+        ALLOWED_ACTIONS = ['contain', 'lift_containment', 'hide_host', 'unhide_host']
+        if action_name.lower() in ALLOWED_ACTIONS:
+            FULL_URL = self.base_url+'/devices/entities/devices-actions/v2'
+            HEADERS = self.headers
+            PARAMS = parameters
+            BODY = body
+            returned = service_request(caller=self,
+                                       method="POST",
+                                       endpoint=FULL_URL,
+                                       params=PARAMS,
+                                       body=BODY,
+                                       headers=HEADERS,
+                                       verify=self.ssl_verify
+                                       )
+        else:
+            returned = generate_error_result("Invalid value specified for action_name parameter.")
+
         return returned
 
     def GetDeviceDetails(self: object, ids) -> dict:
